==> haskell-hspec-meta-2.4.6-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-meta
version: 2.4.6
id: hspec-meta-2.4.6-H8tfFWx7XEz8yW2gKcNciN
key: hspec-meta-2.4.6-H8tfFWx7XEz8yW2gKcNciN
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.
category: Testing
abi: 810040d94e8f67339784aef220205270
exposed: True
exposed-modules:
    Test.Hspec.Meta
hidden-modules: Test.Hspec Test.Hspec.Core Test.Hspec.Discover
                Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
                Test.Hspec.Runner Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
                Test.Hspec.Core.Options Test.Hspec.Core.QuickCheck
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Test.Hspec.Core.Util Data.Algorithm.Diff
                Paths_hspec_meta
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-meta-2.4.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-meta-2.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-meta-2.4.6
hs-libraries: HShspec-meta-2.4.6-H8tfFWx7XEz8yW2gKcNciN
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG array-0.5.2.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl time-1.8.0.2
    transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=0f0d928add941ac9e4a9f5dba9348ac8
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=c680df23e682430249bcd1d9f441fd63
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=a429d798ab9c438c1f0078c2ad19fe61
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html: /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-meta-2.4.6-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-meta
version: 2.4.6
id: hspec-meta-2.4.6-K1WHOie5ZJTX50hG9LUMk
key: hspec-meta-2.4.6-K1WHOie5ZJTX50hG9LUMk
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.
category: Testing
abi: df396c7fbf6f3e1c16bcd39a3e39aff5
exposed: True
exposed-modules:
    Test.Hspec.Meta
hidden-modules: Test.Hspec Test.Hspec.Core Test.Hspec.Discover
                Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
                Test.Hspec.Runner Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
                Test.Hspec.Core.Options Test.Hspec.Core.QuickCheck
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Test.Hspec.Core.Util Data.Algorithm.Diff
                Paths_hspec_meta
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-meta-2.4.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-meta-2.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-meta-2.4.6
hs-libraries: HShspec-meta-2.4.6-K1WHOie5ZJTX50hG9LUMk
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8 array-0.5.2.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl time-1.8.0.2
    transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8=60434811d26166e1bacacf0138207cc4
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=0f0d928add941ac9e4a9f5dba9348ac8
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=c680df23e682430249bcd1d9f441fd63
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=a429d798ab9c438c1f0078c2ad19fe61
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html: /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
